#!/bin/bash

#******************************************************************************
#cronjob for lcg-asis client.
#
# It wakes-up every 5 minutes a client instance which contacts the tank server
# and retrieves the last updates to be installed for each VO
#
# Author: roberto.santinelli@cern.ch
# parameters required: 
#                      1- the VO the user belongs 
#                      2- the name of the host running tank servicce 
#******************************************************************************



#################################################################
#first of all it looks whether the CE host is up or not

is_down=`ping -w 1 $2 | grep -c -i '100% loss'`

if [ "$is_down" -eq 1 ]; then
    echo "server host unreachable: exiting..."
    exit 1
fi
################################################################

source /etc/sysconfig/lcg
LCG_LOCATION=${LCG_LOCATION:=/opt/lcg}
in_file=${LCG_LOCATION}/etc/spark.conf
vo=$1

export EDG_FLAG_DIR=`grep "^${vo}_flagdir" $in_file | awk -F"=" '{print $2}'`/
export LOCAL_INSTALL_DIR=`grep "^${vo}_locdir" $in_file | awk -F"=" '{print $2}'`/
echo $EDG_FLAG_DIR
echo $LOCAL_INSTALL_DIR
RUN=`ps x | grep lcg-spark | grep -v grep | wc -l`

if [ "$RUN" -gt 0 ]; then
    echo "client already running"
    exit 1
fi
my_host=`hostname`

if [ ! -f ${EDG_FLAG_DIR}${my_host} ]; then
    echo ${EDG_FLAG_DIR}${my_host} no present
    echo "host not registered: upgrading functionality called"
    ${LCG_LOCATION}/sbin/lcg-spark -h http://$2:18084 -a upgradehost --vo $1
else
    echo "host already registered: refreshing its content"
    ${LCG_LOCATION}/sbin/lcg-spark -h http://$2:18084 -a refreshhost --vo $1
fi
    
exit 0
